@@ -1,39 +1,7 @@
 #! /usr/local/bin/perl -w
 #
-# brownFreq.pl version 2.01
-# (Last updated $Id: brownFreq.pl,v 1.12 2007/10/09 12:05:41 sidz1979 Exp $)
-#
-# This program reads the Brown Corpus and computes the frequency counts
-# for each synset in WordNet. These frequency counts are used by 
-# various measures of semantic relatedness to calculate the information 
-# content values of concepts. The output is generated in a format as 
-# required by the WordNet::Similarity modules for computing semantic 
-# relatedness.
-#
-# Copyright (c) 2005
-#
-# Ted Pedersen, University of Minnesota, Duluth
-# tpederse at d.umn.edu
-#
-# Satanjeev Banerjee, Carnegie Mellon University, Pittsburgh
-# banerjee+ at cs.cmu.edu
-#
-# Siddharth Patwardhan, University of Utah, Salt Lake City
-# sidd at cs.utah.edu
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-#
+# brownFreq.pl version 2.04
+# (Last updated $Id: brownFreq.pl,v 1.17 2008/04/17 00:55:33 tpederse Exp $)
 #
 # -----------------------------------------------------------------------------
 
@@ -53,6 +21,7 @@ my %topHash;
 use strict;
 use Getopt::Long;
 use WordNet::QueryData;
+use WordNet::Tools;
 
 # First check if no commandline options have been provided... in which case
 # print out the usage notes!
@@ -440,20 +409,39 @@ sub printUsage
 # Subroutine to print the version information
 sub printVersion
 {
-    print "brownFreq.pl version 2.01\n";
-    print "Copyright (c) 2005, Ted Pedersen, Satanjeev Banerjee and Siddharth Patwardhan.\n";
+    print "brownFreq.pl version 2.04\n";
+    print "Copyright (c) 2005-2008, Ted Pedersen, Satanjeev Banerjee and Siddharth Patwardhan.\n";
 }
 
 __END__
 
 =head1 NAME
 
-brownFreq.pl
+brownFreq.pl - Compute Information Content from the Brown Corpus
 
 =head1 SYNOPSIS
 
-brownFreq.pl [--outfile=OUTFILE [--stopfile=STOPFILE] 
- [--wnpath=WNPATH] [--resnik] [--smooth=SCHEME] FILES | --help --version]
+ brownFreq.pl [--outfile=OUTFILE [--stopfile=STOPFILE] 
+	 [--wnpath=WNPATH] [--resnik] [--smooth=SCHEME] FILES 
+	| --help --version]
+
+=head1 DESCRIPTION 
+
+This program reads the Brown Corpus and computes the frequency counts
+for each synset in WordNet. These frequency counts are used by 
+various measures of semantic relatedness to calculate the information 
+content values of concepts. The output is generated in a format as 
+required by the WordNet::Similarity modules for computing semantic 
+relatedness.
+
+There are various forms of the Brown corpus available. The one we 
+use for this program comes from the ICAME Collection of English
+Language Corpora,  Second Edition, 1999. 
+L<http://www.hit.uib.no/icame/cd> 
+
+A more detailed description of how information content is calculated can
+be found in L<rawtextFreq.pl>. This program uses exactly the same
+techniques as described there.
 
 =head1 OPTIONS
 
@@ -494,4 +482,51 @@ B<FILES>
 
     Files for the Brown Corpus (e.g., /home/sid/Brown/BROWN1/*.TXT).
 
+=head1 BUGS
+
+Report to WordNet::Similarity mailing list :
+ L<http://groups.yahoo.com/group/wn-similarity>
+
+=head1 SEE ALSO
+
+L<WordNet::Similarity>
+
+ICAME Corpus : 
+ L<http://www.hit.uib.no/icame/cd> 
+
+WordNet home page : 
+ L<http://wordnet.princeton.edu>
+
+WordNet::Similarity home page :
+ L<http://wn-similarity.sourceforge.net>
+
+=head1 AUTHORS
+
+ Ted Pedersen, University of Minnesota, Duluth
+ tpederse at d.umn.edu
+
+ Satanjeev Banerjee, Carnegie Mellon University, Pittsburgh
+ banerjee+ at cs.cmu.edu
+
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd at cs.utah.edu
+
+=head1 COPYRIGHT
+
+Copyright (c) 2005-2008, Ted Pedersen, Satanjeev Banerjee, and 
+Siddharth Patwardhan
+
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation; either version 2
+of the License, or (at your option) any later version.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
 =cut
